==> coil-1.1.1-javadoc.jar: coil-base/coil.transform/-circle-crop-transformation/index.md <==
[coil-base](../../index.md) / [coil.transform](../index.md) / [CircleCropTransformation](./index.md)

# CircleCropTransformation

`class CircleCropTransformation : `[`Transformation`](../-transformation/index.md)

A [Transformation](../-transformation/index.md) that crops an image using a centered circle as the mask.

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | A [Transformation](../-transformation/index.md) that crops an image using a centered circle as the mask.`CircleCropTransformation()` |

### Functions

| Name | Summary |
|---|---|
| [equals](equals.md) | `fun equals(other: `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`?): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [hashCode](hash-code.md) | `fun hashCode(): `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [key](key.md) | Return a unique key for this transformation.`fun key(): `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [toString](to-string.md) | `fun toString(): `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [transform](transform.md) | Apply the transformation to [input](../-transformation/transform.md#coil.transform.Transformation$transform(coil.bitmap.BitmapPool, android.graphics.Bitmap, coil.size.Size)/input).`suspend fun transform(pool: `[`BitmapPool`](../../coil.bitmap/-bitmap-pool/index.md)`, input: `[`Bitmap`](https://developer.android.com/reference/android/graphics/Bitmap.html)`, size: `[`Size`](../../coil.size/-size.md)`): `[`Bitmap`](https://developer.android.com/reference/android/graphics/Bitmap.html) |

==> coil-1.2.0-javadoc.jar: coil-base/coil.transform/-circle-crop-transformation/index.md <==
[coil-base](../../index.md) / [coil.transform](../index.md) / [CircleCropTransformation](./index.md)

# CircleCropTransformation

`class CircleCropTransformation : `[`Transformation`](../-transformation/index.md)

A [Transformation](../-transformation/index.md) that crops an image using a centered circle as the mask.

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | A [Transformation](../-transformation/index.md) that crops an image using a centered circle as the mask.`CircleCropTransformation()` |

### Functions

| Name | Summary |
|---|---|
| [equals](equals.md) | `fun equals(other: `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`?): `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [hashCode](hash-code.md) | `fun hashCode(): `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [key](key.md) | Return a unique key for this transformation.`fun key(): `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [toString](to-string.md) | `fun toString(): `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [transform](transform.md) | Apply the transformation to [input](../-transformation/transform.md#coil.transform.Transformation$transform(coil.bitmap.BitmapPool, android.graphics.Bitmap, coil.size.Size)/input) and return the transformed [Bitmap](https://developer.android.com/reference/android/graphics/Bitmap.html).`suspend fun transform(pool: `[`BitmapPool`](../../coil.bitmap/-bitmap-pool/index.md)`, input: `[`Bitmap`](https://developer.android.com/reference/android/graphics/Bitmap.html)`, size: `[`Size`](../../coil.size/-size.md)`): `[`Bitmap`](https://developer.android.com/reference/android/graphics/Bitmap.html) |
